@@ -17,7 +17,6 @@ describe 'glance::api' do
       :backlog                        => '<SERVICE DEFAULT>',
       :workers                        => '7',
       :show_image_direct_url          => '<SERVICE DEFAULT>',
-      :show_multiple_locations        => '<SERVICE DEFAULT>',
       :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
       :filesystem_store_file_perm     => '<SERVICE DEFAULT>',
       :location_strategy              => '<SERVICE DEFAULT>',
@@ -25,6 +24,7 @@ describe 'glance::api' do
       :delayed_delete                 => '<SERVICE DEFAULT>',
       :scrub_time                     => '<SERVICE DEFAULT>',
       :enforce_secure_rbac            => '<SERVICE DEFAULT>',
+      :use_keystone_limits            => '<SERVICE DEFAULT>',
       :image_cache_dir                => '/var/lib/glance/image-cache',
       :image_import_plugins           => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
@@ -34,6 +34,11 @@ describe 'glance::api' do
       :node_staging_uri               => '<SERVICE DEFAULT>',
       :worker_self_reference_url      => '<SERVICE DEFAULT>',
       :image_member_quota             => '<SERVICE DEFAULT>',
+      :image_property_quota           => '<SERVICE DEFAULT>',
+      :image_tag_quota                => '<SERVICE DEFAULT>',
+      :image_location_quota           => '<SERVICE DEFAULT>',
+      :image_size_cap                 => '<SERVICE DEFAULT>',
+      :user_storage_quota             => '<SERVICE DEFAULT>',
       :image_cache_stall_time         => '<SERVICE DEFAULT>',
       :image_cache_max_size           => '<SERVICE DEFAULT>',
       :cache_prefetcher_interval      => '<SERVICE DEFAULT>',
@@ -68,6 +73,7 @@ describe 'glance::api' do
         :delayed_delete                 => 'true',
         :scrub_time                     => '10',
         :enforce_secure_rbac            => 'true',
+        :use_keystone_limits            => 'true',
         :image_cache_dir                => '/tmp/glance',
         :image_import_plugins           => 'image_conversion',
         :image_conversion_output_format => 'raw',
@@ -76,7 +82,12 @@ describe 'glance::api' do
         :enabled_import_methods         => 'glance-direct,web-download',
         :node_staging_uri               => '/tmp/staging',
         :worker_self_reference_url      => 'http://worker1',
-        :image_member_quota             => '128',
+        :image_member_quota             => 128,
+        :image_property_quota           => 129,
+        :image_tag_quota                => 130,
+        :image_location_quota           => 10,
+        :image_size_cap                 => 1099511627776,
+        :user_storage_quota             => 0,
         :image_cache_stall_time         => '10',
         :image_cache_max_size           => '10737418240',
         :cache_prefetcher_interval      => '300',
@@ -116,7 +127,7 @@ describe 'glance::api' do
           'tag'        => 'glance-service',
         ) }
 
-        it { is_expected.to_not contain_openstacklib__service_validation('glance-api') }
+        it { is_expected.to_not contain_exec('validate_nova_api') }
         it { is_expected.to contain_glance_api_config("paste_deploy/flavor").with_value(param_hash[:pipeline]) }
 
         it 'is_expected.to lay down default api config' do
@@ -129,6 +140,7 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'enforce_secure_rbac',
+            'use_keystone_limits',
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
@@ -136,6 +148,11 @@ describe 'glance::api' do
             'node_staging_uri',
             'worker_self_reference_url',
             'image_member_quota',
+            'image_property_quota',
+            'image_tag_quota',
+            'image_location_quota',
+            'image_size_cap',
+            'user_storage_quota',
             'limit_param_default',
             'api_limit_max',
           ].each do |config|
@@ -218,13 +235,7 @@ describe 'glance::api' do
         }
       end
 
-      it { is_expected.to contain_service('glance-api').with(
-          'ensure'     => nil,
-          'enable'     => false,
-          'hasstatus'  => true,
-          'hasrestart' => true,
-          'tag'        => 'glance-service',
-        ) }
+      it { is_expected.to_not contain_service('glance-api') }
     end
 
     describe 'with overridden pipeline' do
@@ -266,22 +277,6 @@ describe 'glance::api' do
       end
     end
 
-    describe 'with platform default oslo concurrency lock_path' do
-      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
-        :lock_path => platform_params[:lock_path]
-      )}
-    end
-
-    describe 'with overridden oslo concurrency lock_path' do
-      let :params do
-        {:lock_path => '/glance/lock/path' }
-      end
-
-      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
-        :lock_path => '/glance/lock/path',
-      )}
-    end
-
     describe 'setting enable_proxy_headers_parsing' do
       let :params do
         default_params.merge({:enable_proxy_headers_parsing => true })
@@ -560,15 +555,6 @@ describe 'glance::api' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      let(:platform_params) do
-        case facts[:osfamily]
-        when 'Debian'
-          { :lock_path => '/var/lock/glance' }
-        when 'RedHat'
-          { :lock_path => '/var/lib/glance/tmp' }
-        end
-      end
-
       it_configures 'glance::api'
       it_configures "glance::api #{facts[:osfamily]}"
     end
